@@ -4,7 +4,6 @@
 <context>
     <name>Clipboard</name>
     <message>
-        <location filename="../src/clipboard.cpp" line="60"/>
         <source>Copy color %1 to clipboard</source>
         <translation>將顏色 %1 複製到剪貼簿</translation>
     </message>
@@ -12,12 +11,10 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/main.cpp" line="38"/>
         <source>Deepin Picker is a quick and easy screen color picking tool. RGB and HEX codes are obtained on click and auto saved to the clipboard.</source>
         <translation>Deepin 取色器是款快速且簡單的螢幕取色工具。可透過點選取得 RGB 及十六進位色彩碼，並自動複製到剪貼簿。</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="65"/>
         <source>Deepin Picker</source>
         <translation>Deepin 取色器</translation>
     </message>
